@@ -6,7 +6,7 @@ def create_repo(repo_name, token=None, provider='github'):
   if 'github' in provider:
     g = Github(token)
     user = g.get_user()
-    repo = user.create_repo(repo_name)
+    repo = user.create_repo(repo_name, private=True)
     return repo
 
 def delete_repo(repo_name, token=None, provider='github'):
